Testing entities with AXI interfaces#
The axi provides classes to instantiate AXI interfaces.
These classes wrap around cocotbext-axi and provide a standardized interface across all AXI interface
types.
AXI#
The fully fledged AXI interface.
|
A Wrapper around cocotbext-axi AXI. |
|
A Wrapper around cocotbext-axi AXI RAM. |
|
A generator class that gives back a random payload. |
AXI-Lite#
The lighter AXI-Lite interface.
|
A wrapper class around cocotbext-axi AXI-Lite Master. |
|
A Wrapper around cocotbext-axi AXI-Lite RAM. |
A generator class that gives back a random payload. |
AXI-Stream#
The AXI-Stream interface for streaming applications.
|
A wrapper class around cocotbext-axi AXI-Stream source. |
|
A Wrapper around cocotbext-axi AXI-Stream sink. |
A generator class that gives back a random payload. |
AXI Flags#
AXI related flags and enumeration classes.
|
The burst type used during the AXI write transaction. |
|
The number of bytes in each data transfer in a write transaction. |
|
The AXI Lock type supported by AXI3. |
|
The different bits of the AxCACHE attribute. |
|
The permission signals that can be used to protect against illegal transactions. |
|
The response signals. |